==> nextcloud-app-calendar-1%3A1.7.2-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/calendar/l10n/ia.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Calendario",
    "Hello," : "Salute %s,",
    "Cheers!" : "Congratulationes!",
    "Too many redirects. Aborting ..." : "Troppo redirectiones. Annullante ....",
    "The remote server did not give us access to the calendar (HTTP {%s} error)" : "Le servitor remote non dava nos accesso al calendario (error HTTP {%s})",
    "Error connecting to remote server" : "Error durante que connecteva al servitor remote",
    "Error requesting resource on remote server. This could possible be related to a certificate mismatch" : "Error durante que connecteva al servitor remote. Isto possibilemente refere se a un incompatibilitate de certificato.",
    "Error requesting resource on remote server" : "Error durante que sollicitava ressource in le servitor remote",
    "Individual" : "Individuo",
    "Group" : "Gruppo",
    "Resource" : "Ressource",
    "Room" : "Sala",
    "Unknown" : "Incognite",
    "Required" : "Requirite",
    "Optional" : "Optional",
    "Does not attend" : "No frequenta",
    "{name} ({email})" : "{name} ({email})",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "Tu es in un fuso horari incognite ({tz}), recadente a UTC",
    "Please create a calendar first." : "Per favor, primarimente crea un calendario.",
    "New event" : "Nove evento",
    "CalDAV address for clients" : "Adresse CalDAV pro clientes",
    "Some events in this calendar are broken. Please check the JS console for more info." : "Alcun eventos in iste calendario es rupte. Per favor, verifica le consola JS pro plus information.",
    "Share Calendar" : "Comparti Calendario",
    "Shared" : "Compartite",
    "WebDAV address for subscriptions" : "Adresse WebDAV pro subscriptiones",
    "group" : "gruppo",
    "Details" : "Detalios",
    "Attendees" : "Participantes",
    "Reminders" : "Memento",
    "Repeating" : "Repetente",
    "When shared show full event" : "Quando compartite, monstrar evento integremente",
    "When shared show only busy" : "Quando compartite, monstrar solo si illo es occupate",
    "When shared hide this event" : "Quando compartite, celar iste evento",
    "Confirmed" : "Confirmate",
    "Tentative" : "Tentative",
    "Cancelled" : "Annullate",
    "Global" : "Global",
    "None" : "Nulle",
    "Every day" : "Quotidianmente",
    "Every week" : "Septimanalmente",
    "Every month" : "Mensualmente",
    "Every year" : "Annualmente",
    "never" : "nunquam",
    "after" : "post",
    "How about getting started by importing some calendars?" : "Que dicerea tu de initiar a importar alcun calendarios?",
    "At time of event" : "Al momento del evento",
    "5 minutes before" : "5 minutas antea",
    "10 minutes before" : "10 minutas antea",
    "15 minutes before" : "15 minutas antea",
    "30 minutes before" : "30 minutas antea",
    "1 hour before" : "1 hora antea",
    "2 hours before" : "2 horas antea",
    "Custom" : "Personalisate",
    "Audio" : "Audio",
    "Pop-up" : "Pop-up",
    "sec" : "secundas",
    "min" : "minutas",
    "hours" : "horas",
    "days" : "dies",
    "week" : "septimana",
    "before" : "antea",
    "start" : "initio",
    "end" : "fin",
    "Editing reminders of unknown type not supported." : "Modificar mementos de typos incognite non es supportate.",
    "Week {number} of {year}" : "Septimana {number} de {year}",
    "{type} {time} before the event starts" : "{type} {time} ante que le evento initia",
    "{type} {time} before the event ends" : "{type} {time} ante que le evento fini",
    "{type} {time} after the event starts" : "{type} {time} post que le evento initia",
    "{type} {time} after the event ends" : "{type} {time} post que le evento fini",
    "{type} at the event's start" : "{type} al momento del initio del evento",
    "{type} at the event's end" : "{type} al momento del fin del evento",
    "{type} at {time}" : "{type} a {time}",
    "{calendar} shared by {owner}" : "{calendar} compartite per {owner}",
    "Please enter a valid WebCal-URL" : "Per favor, insere un adresse URL de WebCal valide",
    "Severe error in webcal proxy. Please contact administrator for more information." : "Error grave in le servitor proxy de WebCal. Per favor, contacta le administrator pro plus informationes.",
    "Title of the Event" : "Titulo del Evento.",
    "Starts" : "Comencia",
    "Ends" : "Fini",
    "All day Event" : "Evento de un die plen",
    "Delete" : "Deler",
    "Cancel" : "Cancellar",
    "More ..." : "Plus ...",
    "Create" : "Crear",
    "Update" : "Actualisar",
    "Close" : "Clauder",
    "Location" : "Loco",
    "Description" : "Description",
    "Event status" : "Stato del evento",
    "Visibility when sharing" : "Visibilitate quando compartite",
    "Export" : "Exportar",
    "%s has published the calendar %s" : "%s ha publicate le calendario %s",
    "We wanted to inform you that %s has published the calendar {boldstart}%s{boldend}." : "Nos vole informar te que %s ha publicate le calendario {boldstart}%s{boldend}.",
    "Click here to access it" : "Clicca ci pro acceder lo.",
    "We wanted to inform you that %s has published the calendar %s." : "Nos vole informar te que %s ha publicate le calendario %s.",
    "Click on the link below to access it" : "Clicca super le ligamine infra pro acceder lo",
    "Day" : "Die",
    "Week" : "Septimana",
    "Month" : "Mense",
    "Today" : "Hodie",
    "More" : "Plus",
    "Edit" : "Modificar",
    "Link" : "Ligamine",
    "iCal link" : "Ligamine iCal",
    "Download" : "Discargar",
    "can edit" : "pote modificar",
    "Share link" : "Compartir ligamine",
    "Public access" : "Accesso public",
    "Email link to person" : "Ligamine via e-posta a un persona",
    "Send" : "Invia",
    "New Calendar" : "Nove calendario",
    "Name" : "Nomine",
    "New Subscription" : "Nove Subscription",
    "Go back" : "Retornar",
    "Go forward" : "Avantiar",
    "Edit event" : "Modificar evento",
    "Delete Event" : "Deler Evento",
    "Save Event" : "Salveguardar Evento",
    "Time" : "Tempore",
    "Type" : "Typo",
    "Relative" : "Relative",
    "Absolute" : "Absolute",
    "Repeat" : "Repeter",
    "times every" : "vices tote",
    "Add" : "Adder",
    "Please add your email address in the personal settings in order to add attendees." : "Per favor, adde tu adresse de e-posta in le configurationes personal pro adder participantes.",
    "from" : "ex",
    "to" : "a",
    "This event's repeating rule is not supported yet." : "Iste regula de repetition de evento non es ancora supportate.",
    "Support for advanced rules will be added with subsequent updates." : "Supporto a regulas avantiate essera addite in actualisationes subsequente.",
    "Reset repeating rule" : "Reinitialisar regula de repetition",
    "Repeat every ..." : "Repeter cata ...",
    "end repeat ..." : "finir repetition ...",
    "times" : "vices",
    "Import Calendars" : "Importar Calendarios",
    "Import canceled" : "Importar cancellate",
    "Analyzing calendar" : "Analysante calendario",
    "The file contains objects incompatible with the selected calendar" : "Le file contine objectos incompatibile con le calendario selectionate",
    "New calendar" : "Nove calendario",
    "File is empty" : "File es vacue",
    "Import scheduled" : "Importar eventos inscribite",
    "Publish URL" : "Publicar adresse URL",
    "Settings & import" : "Configurationes e importation",
    "Import calendar" : "Importar calendario",
    "No Calendars selected for import" : "Nulle Calendarios selectionate pro importar",
    "Skip simple event editor" : "Saltar modificator de eventos simple",
    "Show week numbers" : "Monstrar le numero del septimanas",
    "Primary CalDAV address" : "Adresse de CalDAV primari"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-calendar-1%3A2.0.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/calendar/l10n/ia.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Calendario",
    "Hello," : "Salute %s,",
    "Cheers!" : "Congratulationes!",
    "Today" : "Hodie",
    "Day" : "Die",
    "Week" : "Septimana",
    "Month" : "Mense",
    "Download" : "Discargar",
    "Delete" : "Deler",
    "Share link" : "Compartir ligamine",
    "Share with users or groups" : "Compartir con usatores o gruppos",
    "can edit" : "pote modificar",
    "New calendar" : "Nove calendario",
    "Cancel" : "Cancellar",
    "Automatic" : "Automatic",
    "Show week numbers" : "Monstrar le numero del septimanas",
    "Settings & import" : "Configurationes e importation",
    "Email" : "E-posta",
    "Unknown" : "Incognite",
    "from" : "ex",
    "to" : "a",
    "never" : "nunquam",
    "after" : "post",
    "Repeat" : "Repeter",
    "Monday" : "Lunedi",
    "Summary" : "Summario",
    "More" : "Plus",
    "Save" : "Salveguardar",
    "Update" : "Actualisar",
    "Personal" : "Personal",
    "Details" : "Detalios",
    "Attendees" : "Participantes",
    "Reminders" : "Memento",
    "Activity" : "Activitate",
    "Close" : "Clauder",
    "Anniversary" : "Anniversario de evento",
    "Week {number} of {year}" : "Septimana {number} de {year}",
    "Daily" : "Cata die",
    "Weekly" : "Cata septimana",
    "When shared show full event" : "Quando compartite, monstrar evento integremente",
    "When shared show only busy" : "Quando compartite, monstrar solo si illo es occupate",
    "When shared hide this event" : "Quando compartite, celar iste evento",
    "Location" : "Loco",
    "Description" : "Description",
    "Confirmed" : "Confirmate",
    "Tentative" : "Tentative",
    "Cancelled" : "Cancellate",
    "Presentation" : "Presentation",
    "Mail" : "Posta",
    "Play" : "Reproducer",
    "Global" : "Global"
},
"nplurals=2; plural=(n != 1);");
